import { renderHook, waitFor } from '@testing-library/react';
import { rest } from 'msw';
import { setupServer } from 'msw/node';
import { useUsers } from './Users.hooks';

const server = setupServer();

beforeAll(() => server.listen());
afterEach(() => server.resetHandlers());
afterAll(() => server.close());


test('users配列がAPIから取得される', async () => {
  // APIのmock
  server.use(
    rest.get('/api/users', (req, res, ctx) => {
      return res(ctx.json({ users: [{ name: 'alpha' }, { name: 'bravo' }] }));
    })
  );

  const { result } = renderHook(() => useUsers());

  // APIのコール終了まで待ち受ける
  await waitFor(() => {
    return expect(result.current.users).toStrictEqual(['alpha', 'bravo']);
  });
});
