import { render, screen, fireEvent } from '@testing-library/react';
import Users from './Users';
import { useUsers } from './Users.hooks'
import renderer from 'react-test-renderer';

jest.mock('./Users.hooks', () => {
  return {
    useUsers: jest.fn()
  };
});

test('renders Users', () => {
  useUsers.mockImplementation(() => {
    return {
      users: ['alpha', 'bravo']
    }
  });

  render(<Users />);

  expect(screen.getByText('alpha')).toBeInTheDocument();
  expect(screen.getByText('bravo')).toBeInTheDocument();
});

test('追加ボタンのsubmitでsubmitが呼び出される', () => {
  const submitMock = jest.fn()

  useUsers.mockImplementation(() => {
    return {
      users: ['alpha', 'bravo'],
      submit: submitMock
    }
  });

  render(<Users />);

  fireEvent.submit(screen.getByText('追加'));

  expect(submitMock).toHaveBeenCalledTimes(1);
});

test('Usersコンポーネントのスナップショットテスト', () => {
  useUsers.mockImplementation(() => {
    return {
      users: ['alpha', 'bravo']
    }
  });

  const component = renderer.create(<Users />);

  const tree = component.toJSON();
  // スナップショットファイルと比較
  expect(tree).toMatchSnapshot();
});
